@@ -6,10 +6,12 @@ from .bitbox02 import BitBox02
 from .keepkey import Keepkey
 from .specter import Specter
 from .cobo import Cobo
+from .jade import Jade
 from .generic import GenericDevice
 from .electrum import Electrum
 from .bitcoin_core import BitcoinCore
 from .elements_core import ElementsCore
+from .seedsigner import SeedSignerDevice
 
 # all device types
 __all__ = [
@@ -20,6 +22,8 @@ __all__ = [
     ColdCard,
     Keepkey,
     Cobo,
+    Jade,
+    SeedSignerDevice,
     Electrum,
     BitcoinCore,
     ElementsCore,
