@@ -2,7 +2,7 @@ import hashlib
 
 # from ..device import Device
 from .coldcard import ColdCard
-from hwilib.serializations import PSBT
+from hwilib.psbt import PSBT
 from binascii import a2b_base64
 from ..util import bcur
 from ..util.base43 import b43_encode
@@ -21,15 +21,10 @@ class Cobo(ColdCard):
     exportable_to_wallet = True
     wallet_export_type = "qr"
 
-    def __init__(self, name, alias, keys, fullpath, manager):
-        super().__init__(name, alias, keys, fullpath, manager)
-
     def create_psbts(self, base64_psbt, wallet):
         psbts = super().create_psbts(base64_psbt, wallet)
         # make sure nonwitness and xpubs are not there
         psbts["qrcode"] = wallet.fill_psbt(base64_psbt, non_witness=False, xpubs=False)
-        # see cc class
-        self.replace_derivations(wallet, psbts)
         raw_psbt = a2b_base64(psbts["qrcode"])
         enc, hsh = bcur.bcur_encode(raw_psbt)
         qrpsbt = ("ur:bytes/%s/%s" % (hsh, enc)).upper()
