@@ -7,12 +7,11 @@ from ..device import Device
 class Electrum(Device):
     device_type = "electrum"
     name = "Electrum"
+    icon = "electrum_icon.svg"
 
     sd_card_support = True
     qr_code_support = True
-
-    def __init__(self, name, alias, keys, fullpath, manager):
-        super().__init__(name, alias, keys, fullpath, manager)
+    qr_code_animate = "off"
 
     def create_psbts(self, base64_psbt, wallet):
         # remove non_witness utxo for QR code
