@@ -22,9 +22,6 @@ class Specter(SDCardDevice):
     supports_hwi_multisig_display_address = True
     liquid_support = True
 
-    def __init__(self, name, alias, keys, blinding_key, fullpath, manager):
-        super().__init__(name, alias, keys, blinding_key, fullpath, manager)
-
     def create_psbts(self, base64_psbt, wallet):
         try:
             # remove rangeproofs and add sighash alls
