@@ -10,9 +10,6 @@ class Trezor(HWIDevice):
     supports_hwi_toggle_passphrase = True
     supports_hwi_multisig_display_address = True
 
-    def __init__(self, name, alias, keys, blinding_key, fullpath, manager):
-        HWIDevice.__init__(self, name, alias, keys, blinding_key, fullpath, manager)
-
     @classmethod
     def get_client(cls, *args, **kwargs):
         return TrezorClient(*args, **kwargs)
