@@ -175,9 +175,15 @@ class Specter:
         try:
             return self.node_manager.active_node
         except SpecterError as e:
+            logger.error("SpecterError while accessing active_node")
+            logger.exception(e)
             self.update_active_node(list(self.node_manager.nodes.values())[0].alias)
             return self.node_manager.active_node
 
+    @property
+    def default_node(self):
+        return self.node_manager.default_node()
+
     @property
     def rpc(self):
         return self.node.rpc
@@ -186,6 +192,10 @@ class Specter:
     def utxorescanwallet(self):
         return self.node.utxorescanwallet
 
+    @utxorescanwallet.setter
+    def utxorescanwallet(self, value):
+        self.node.utxorescanwallet = value
+
     @property
     def config(self):
         """A convenience property simply redirecting to the config_manager"""
@@ -463,14 +473,6 @@ class Specter:
     def is_liquid(self):
         return is_liquid(self.chain)
 
-    @property
-    def is_liquid(self):
-        return is_liquid(self.chain)
-
-    @property
-    def is_liquid(self):
-        return is_liquid(self.chain)
-
     @property
     def user_config(self):
         return self.config if self.user.is_admin else self.user.config
@@ -629,6 +631,7 @@ class Specter:
                 "mainnet",
                 "0.20.1",
             )
+            logger.info(f"persisting {internal_node} in migrate_old_node_format")
             write_node(
                 internal_node,
                 os.path.join(
@@ -654,6 +657,7 @@ class Specter:
                 os.path.join(os.path.join(self.data_folder, "nodes"), "default.json"),
                 self,
             )
+            logger.info(f"persisting {node} in migrate_old_node_format")
             write_node(
                 node,
                 os.path.join(os.path.join(self.data_folder, "nodes"), "default.json"),
